;----------------------------------------------;
;     "Preferences Falsification" (PFS)        ;
;     Created by: F. León & J. Tena            ;
;     Coded by: F.J. Miguel (LSDS-UAB)         ;
;     Version: 1.4 (no shocks) Jun. 2019       ;
;----------------------------------------------;

;;    "Preferences Falsification" (PreFalSim) its a simulation model based on Kuran's Model
;;    It allows to overcome some of the main limitations of Kuran's models.
;;
;;    This program is free software: you can redistribute it and/or modify
;;    it under the terms of the GNU General Public License as published by
;;    the Free Software Foundation, either version 3 of the License, or
;;    (at your option) any later version.
;;
;;    This program is distributed in the hope that it will be useful,
;;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;    GNU General Public License for more details.
;;
;;    You should have received a copy of the GNU General Public License
;;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;    Contact information:
;;    Francesc J. MIGUEL QUESADA
;;    Laboratory for Socio-Historical Dynamics Simulation (LSDS)
;;    Universitat Autònoma de Barcelona, Catalunya, España.
;;    e-mail: lsds@uab.cat / miguel.quesada@uab.cat

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;     Variable Declaration        ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Globals
globals [
  newclass
  newcolor
  PHI
  GOt-1          ; "General opinion", x-private-opinion mean from previous turn
  Rsz
  Rsx
  fakers-0
  fakers-1
  fakers
  social-list
  ExpectedZ
  eee
  GOt-1-prov
  Xmean          ; x-private-opinion mean
  Xdev           ; x-private-opinion deviation
  Zmean          ; z-public-declaration mean
  Zdev           ; z-public-declaration deviation
  Fprob          ; fakers / population (0-1) or F-probability
  F1prob         ; fakers-1 / population (0-1) or F1-probability
  F0prob         ; fakers-0 / population (0-1) or F0-probability
  cumfakers-0
  cumfakers-1
  meanfakers-0
  meanfakers-1
]

;; Agents Attributes
patches-own [
  class
  group
  rank
  x-private-opinion
  y-threshold-falsification
  y-prov-threshold-falsification    ;;; for provisional round computations
  k-threshold-valid-rounds   ;;; Taken from k slider (default 3)
  v-last-valid-rounds
  z-public-declaration  ;;; {-/0/1}
  z-social-map          ;;; The opinion that j expressed in his LAST interaction with i, if no interaction the rank is used as a proxy.
  SVFcount              ;;; Succesive Valid Falsifications to count past "valid" falsifications.
  H-Festinger?          ;;; Coherence heuristic triggered {false/true}
  H-Goffman?            ;;; Impression Management heuristic triggered {false/true}
  my-Sj                 ;;; rank of current (t) higest rank neighbour
  my-ZSj                ;;; Last remembered public expression of current (t) higest rank neighbour
  my-p
  EOi
  ROi
  GOit-1                ;;; "Perceived general opinion", noise-added to GOt-1 (previous turn x-private-opinion mean)
  fake                  ;;; {no/0/1}
  Why-To-Fake           ;;; The reason to fake opinion {}
  round-declaration?    ;;; {false/true}
]

;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup Functions ;;;
;;;;;;;;;;;;;;;;;;;;;;;

;;; Inicializing the WORLD

to setup
 clear-all
print "-----------------"
print date-and-time
 file-close-all
 resize-world 0 39 0 39
 set eee 1.0E-10              ;;; Use eee to prevent division by zero
 ask patches with [pxcor < 10] [ set class "High" set pcolor blue ]
 ask patches with [pxcor > 9 and pxcor < 20] [ set class "Medium" set pcolor orange ]
 ask patches with [pxcor > 19 and pxcor < 30] [ set class "Low" set pcolor red ]
 ask patches with [pxcor > 29] [ set class "Medium" set pcolor orange ]
 ask n-of ( round ( ( 1 - segregation_level ) * count patches) ) patches [ set class "Change" ]
 ask patches with [ class = "Change" ]
     [
       ask one-of patches with [ class = "Change" and pcolor != [pcolor] of myself ]
           [
             set newclass class set newcolor pcolor
             set class [class] of myself
             set pcolor [pcolor] of myself
           ]
       set class newclass
       set pcolor newcolor
     ]
 ask patches with [ class = "Change" ]
     [
       if pcolor = blue [ set class "High" ]
       if pcolor = orange [ set class "Medium" ]
       if pcolor = red [ set class "Low" ]
     ]

;;; Inicializing AGENTS

  ask patches [ set rank -1 ]   ;;; rank not assigned
  ask n-of  17 patches with [ (class = "Low") AND (rank < 0) ] [ set rank 0.0 ]                          ;;;  17 => rank 0
  ask n-of  50 patches with [ (class = "Low") AND (rank < 0) ] [ set rank 0.05 + random-float 0.10 ]     ;;;  50 => rank U~[0.05,0.15]
  ask n-of 133 patches with [ (class = "Low") AND (rank < 0) ] [ set rank 0.15 + random-float 0.10 ]     ;;; 133 => rank U~[0.15,0.25]
  ask n-of 200 patches with [ (class = "Low") AND (rank < 0) ] [ set rank 0.25 + random-float 0.10 ]     ;;; 200 => rank U~[0.25,0.35]
  ask n-of 246 patches with [ (class = "Medium") AND (rank < 0) ] [ set rank 0.35 + random-float 0.10 ]  ;;; 246 => rank U~[0.35,0.45]
  ask n-of 308 patches with [ (class = "Medium") AND (rank < 0) ] [ set rank 0.45 + random-float 0.10 ]  ;;; 308 => rank U~[0.45,0.55]
  ask n-of 246 patches with [ (class = "Medium") AND (rank < 0) ] [ set rank 0.55 + random-float 0.10 ]  ;;; 246 => rank U~[0.55,0.65]
  ask n-of 200 patches with [ (class = "High") AND (rank < 0) ] [ set rank 0.65 + random-float 0.10 ]    ;;; 200 => rank U~[0.65,0.75]
  ask n-of 133 patches with [ (class = "High") AND (rank < 0) ] [ set rank 0.75 + random-float 0.10 ]    ;;; 133 => rank U~[0.75,0.85]
  ask n-of  50 patches with [ (class = "High") AND (rank < 0) ] [ set rank 0.85 + random-float 0.10 ]    ;;;  50 => rank U~[0.85,0.95]
  ask n-of  17 patches with [ (class = "High") AND (rank < 0) ] [ set rank 1.0 ]                         ;;;  17 => rank 1

 ask patches [
     set rank precision rank 2
     set x-private-opinion rank
     set z-public-declaration ifelse-value ( x-private-opinion < 0.5 ) [ 0 ] [ 1 ]
     set round-declaration? false
     set y-threshold-falsification                    ;;; if x>0.5 => U[0.0,0.5] and if x<0.5 => U[0.5,1.0] (v1.4)
         precision ( random-float 0.5 + ifelse-value ( x-private-opinion < 0.5 ) [ 0.5 ] [ 0 ] ) 2
     set k-threshold-valid-rounds k                   ;;; From k slider
     set v-last-valid-rounds 1 + random 10            ;;; INITIAL PREVIOUS (t-k) VALID ROUNDS random-uniform [1,10]
     set H-Festinger? false
     set H-Goffman? false
     set fake "no"
     set Why-To-Fake ""

     ] ;;; end of Inicializing AGENTS

  set GOt-1 precision mean [x-private-opinion] of patches 2

 ask patches [
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; INITIAL SVFcount as 0 (v1.4)
     set SVFcount 0
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; INITIAL general opinion (biassed)
     set GOit-1 noise GOt-1
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; INITIAL social-map (empty list),
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;; will be builded in runtime as [ [ (patch 0 0) 0 ] [ (patch 0 1) 1 ] [ (patch 1 1) 0 ] ... [ (patch A B) Z ] ]
     set z-social-map []
     ]

 reset-ticks
end

;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Runtime Functions ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Main Procedure
to go
  ifelse ticks < Rounds
    [
      make-groups
      ask patches
          [ festinger-heuristic ]   ;;; Coherence heuristic: “match your private opinion with the one you most frequently defended in public if lately they differed more often than they did not”.
      ask patches
          [ goffman-heuristic ]     ;;; Impression management heuristic: "opinions of low rank agents are consciously hidden when they face higher rank agents with different opinions.".
      ask patches
          [
            reference-opinion       ;;; expectations to face according to own memory of past interactions and knowledge of the general opinion of the population.
            set round-declaration? false
            social-proof-heuristic  ;;; “falsify your preferences if enough others support for the opinion that you dislike”.
            set round-declaration? true
          ]                         ;;; run both procedures: for allowing "later" agents to consider NOT the expectation BUT the actual declaration.

      ask patches
          [
            update-z-social-map     ;;; update the agents' "social-map" by scanning and processing the new neighborhood.
            register-round          ;;; check if present round is a "valid falsification" and update the SVFcount.
          ]
      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; Count fakers, Show if activated, and reset round-declaration
      ask patches [
          if any? turtles [ ask turtles-here [die] ]
          if ( x-private-opinion < 0.5 ) AND ( ROi >= y-prov-threshold-falsification )
             [ set fake 1
               if SeeFakers? [ sprout 1 [ set shape "1" ] ]
             ]
          if ( x-private-opinion >= 0.5 ) AND ( ROi < y-prov-threshold-falsification )
             [ set fake 0
               if SeeFakers? [ sprout 1 [ set shape "0"] ]
            ]
          ]
      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; Update ploting data
      set fakers-0 count patches with [ fake = 0 ]
      set cumfakers-0 cumfakers-0 + fakers-0
      set meanfakers-0 precision (cumfakers-0 / (ticks + eee)) 0
      set fakers-1 count patches with [ fake = 1 ]
      set cumfakers-1 cumfakers-1 + fakers-1
      set meanfakers-1 precision (cumfakers-1 / (ticks + eee)) 0
      set fakers fakers-0 + fakers-1

      set GOt-1 precision mean [z-public-declaration] of patches 2       ;;; update General Declaration (Z) to be used next round
      set Xmean precision mean [x-private-opinion] of patches 2          ;;; update General Opinion (X)

      set Xdev precision sqrt variance [x-private-opinion] of patches 2
      set Zmean GOt-1
      set Zdev precision sqrt variance [z-public-declaration] of patches 2
      set Fprob precision ( fakers / 1600 ) 2
      set F1prob precision ( fakers-1 / 1600 ) 2
      set F0prob precision ( Fprob - F1prob ) 2

      tick
    ]
    [
      stop
    ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Auxiliar Functions   ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to festinger-heuristic                    ;;; Coherence heuristic. Triggered when previous k successive "valid" falsifications.
                                          ;;; Review for v1.0: "simply make it a weighted average of private vs recently expressed opinion"
  ifelse SVFcount = k-threshold-valid-rounds     ;;; COHERENCE condition trigger
     [
      set H-Festinger? true
      set SVFcount 0                  ;;;Case B2 Festinger (fake & k=3) = ERASE
      set x-private-opinion precision ( (0.5 * z-public-declaration) + (0.5 * x-private-opinion) ) 2
      set y-threshold-falsification precision ( 1 - x-private-opinion ) 2
     ] ;;;end of COHERENCE condition
     [
      set H-Festinger? false
     ]

end

to goffman-heuristic
if rank < 0.5                        ;;; Impression Management Heuristic is restricted to low-rank agents.
  [
   set H-Goffman? false
   let Ij max-one-of other patches with [ group = [group] of myself ] [rank]  ;;; Highest rank agent in the activated neighborhood
   let Sj [rank] of Ij                ;;; rank of Ij
   let Xj [x-private-opinion] of Ij     ;;; Opinion of Ij
   let Zj round Xj                      ;;; "My remembered" public opinion of Ij (by defaulf, same of Xj for the initial rounds -no z-social-map)
   foreach z-social-map [ [?1] -> if member? Ij ?1 [ set Zj item 1 ?1 ] ]
   set my-Sj Sj
   set my-ZSj Zj

   if ( (x-private-opinion < 0.5) AND (Zj = 1) ) [ set H-Goffman? true  ]          ;;; CASE "A"
   if ( (x-private-opinion >= 0.5) AND (Zj = 0) ) [ set H-Goffman? true  ]         ;;; CASE "B"

    ifelse H-Goffman?
      [ ;;; Goffman triggered
        let Dij ( 1 + abs (rank - Sj) )
        if Dij = 0 [set Dij eee]
        let aux ( ( abs ( y-threshold-falsification - x-private-opinion ) ) / Dij )

        ifelse Zj = 1
            [ set y-prov-threshold-falsification ( x-private-opinion + aux ) ]   ;;; CASE "A"
            [ set y-prov-threshold-falsification ( x-private-opinion - aux ) ]   ;;; CASE "B"

        set y-prov-threshold-falsification precision y-prov-threshold-falsification 2
      ]
      [ ;;; Goffman NOT triggered
        set y-prov-threshold-falsification precision y-threshold-falsification 2
      ]
  ] ;;; close rank filter
end

to reference-opinion
   let SumWjZt-1 0
   let SumWj 0
   let Wj 0

   ask other patches with [ group = [group] of myself ]                     ;;; The reference group MN neighborhood for t
            [
              ifelse ticks > 0
                     [ foreach [z-social-map] of myself
                        [ [?1] ->
                          if member? self ?1 [ set ExpectedZ item 1 ?1 ]    ;;; Use z-social-map expected Z value for group members
                        ]
                       ;;; BUT if the group memeber has already "declared", replace if for Z actual value.
                       if round-declaration? [ set ExpectedZ z-public-declaration ]
                     ]
                     [ set ExpectedZ rank ]                               ;;; Proxy for tick 0 interactions
              set SumWjZt-1 ( SumWjZt-1 + ExpectedZ )                       ;;; Use Z from the z-social-map
              set SumWjZt-1 precision SumWjZt-1 2
            ]
   set EOi precision ( SumWjZt-1 / 16 ) 2
   set ROi precision ( ( p * GOit-1 ) + ( ( 1 - p ) * EOi ) ) 2
end

to social-proof-heuristic
     set z-public-declaration ifelse-value ( ROi >= y-prov-threshold-falsification ) [ 1 ] [ 0 ]

     ;;; Registering the Falsification event for the present round
     if z-public-declaration = round x-private-opinion [ set fake "no" ]
     if z-public-declaration > round x-private-opinion [ set fake "1" ]
     if z-public-declaration < round x-private-opinion [ set fake "0" ]
end

to register-round  ;;; Register present round as "valid" falsification or not, or reset the counter.

ifelse fake = "no"
  [ ;;;Case B1 (if fake = "no")
    set SVFcount 0
    set Why-To-Fake ""
  ]
  [ ;;; Valid falsifications (+1)
    ifelse H-Goffman?
    [
      ifelse ROi > y-threshold-falsification
         [ ;;;Case F3 (fake & Goffman & ROi>y) = VALID
           set SVFcount SVFcount + 1
           set Why-To-Fake "Irrelevant Goffman (F3)"
         ]
         [
           set Why-To-Fake "Due to Goffman (F2)"
         ]
    ]
    [ ;;;Case F1 (fake & NO-Goffman) = VALID
      set SVFcount SVFcount + 1
      set Why-To-Fake "Without Goffman (F1) "
    ]
  ]
end

to make-groups
   ask patches [set group ""]
   ask one-of patches [ sprout 1
       [
       set hidden? true
       set heading 0
       let aux-group 0
       while [ aux-group < 100 ]
         [
          repeat 10
                 [
                 set aux-group aux-group + 1
                 ask patch-here [
                     set group aux-group
                     ( foreach [ 1 2 3 0 1 2 3 0 1 2 3 0 1 2 3] [ 0 0 0 1 1 1 1 2 2 2 2 3 3 3 3 ]
                           [ [?1 ?2] -> ask patch-at ?1 ?2 [ set group aux-group ] ] )
                     ]
                 fd 4
                 ]
          rt 90 fd 4 rt -90
          ]
        die
        ]
       ]
end

to update-z-social-map
   set social-list []
   ask other patches with [ group = [group] of myself ]                               ;;; The reference group MN neighborhood for t
       [ set social-list lput ( list self z-public-declaration ) social-list ]        ;;; Build social-list as a list of neighbors and Z's [ [(agent 0 0) 0] [(agent 0 1) 1] ... ]
   if length z-social-map = 0 [ set z-social-map social-list ]                        ;;; First round: Inicialize z-social-map

   ;;; The "new" social map will contain ALL the current round novelties (the social-list)...
   let new-social-map social-list
   ;;; ...plus ALL the "historical" information that WAS at the previous z-social-map BUT NOT at the current social-list.
   foreach z-social-map                                                               ;;; Explore each z-social-map agent...
       [ [?1] ->
         let sl 0
         while [ sl < length social-list ]                                            ;;; Enter loop for exploring each z-social-map agent
               [
                 if ( item 0 ?1 = item 0 item sl social-list )                         ;;; If an agent is BOTH at z-social-map and social-list...
                    [ set sl length social-list ]                                     ;;; ...nothing happens, explore next z-social-map agent
                 set sl sl + 1                                                        ;;; continue exploring the rest of social-list agents.
               ]
         if sl = length social-list                                                   ;;; If exit the loop WITHOUT find a z-social-map agent in the new social-list...
            [
              set new-social-map lput ?1 new-social-map
            ]
       ]
   set z-social-map new-social-map                                                    ;;; Update z-social-map
end

to-report noise [ g ]                                         ;;; Each agent misperceive the general opinion
  let aux precision ( g + (random-normal 0.5 0.05) - 0.5 ) 2  ;;; Add some "noise"
  report min (list max (list aux 0 ) 1 )                      ;;; Truncate to (0,1)
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
738
539
-1
-1
13.0
1
10
1
1
1
0
1
1
1
0
39
0
39
1
1
1
ticks
30.0

BUTTON
12
180
99
213
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
18
10
198
39
Preference Falsification v1.4\n==================
10
0.0
1

SLIDER
14
39
198
72
segregation_level
segregation_level
0
1
0.7
0.1
1
NIL
HORIZONTAL

SLIDER
14
108
198
141
Rounds
Rounds
1
1000
500.0
1
1
NIL
HORIZONTAL

BUTTON
102
180
195
213
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
14
141
198
174
k
k
2
10
3.0
1
1
valid rounds
HORIZONTAL

SLIDER
14
71
198
104
p
p
0
1.0
0.7
0.1
1
NIL
HORIZONTAL

MONITOR
872
10
1004
51
General Declaration (Z)
GOt-1
2
1
10

MONITOR
742
201
830
242
False 0
fakers-0
0
1
10

MONITOR
830
201
918
242
False 1
fakers-1
0
1
10

PLOT
741
51
1004
201
The Falsificators
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Fake 0" 1.0 0 -14985354 true "" "plot fakers-0"
"Fake 1" 1.0 0 -8053223 true "" "plot fakers-1"
"Mean F-0" 1.0 2 -8275240 true "" "plot cumfakers-0 / (ticks + eee)"
"Mean F-1" 1.0 2 -1604481 true "" "plot cumfakers-1 / (ticks + eee)"

MONITOR
919
201
1004
242
Falsificators
(word fakers \" (\" precision (fakers / 1600 * 100) 1 \"%)\")
0
1
10

SWITCH
742
506
887
539
SeeFakers?
SeeFakers?
1
1
-1000

MONITOR
741
10
873
51
General Opinion (X)
Xmean
2
1
10

TEXTBOX
21
271
191
358
RUN VERSION\n=====================\n- experiments at Behavoiur Space\n- no debuging extra outputs\n- no programable shocks\n
10
0.0
1

MONITOR
743
243
831
288
Mean F-0
meanfakers-0
0
1
11

MONITOR
830
243
919
288
Mean F-1
meanfakers-1
0
1
11

PLOT
745
305
1006
499
Distrib X
X
n
0.0
1.0
0.0
100.0
true
false
"" ""
PENS
"X" 0.05 1 -16777216 true "" "histogram [x-private-opinion] of patches"

@#$#@#$#@
## WHAT IS IT?

A model for simulating the evolution of individual's preferences, incliding adaptive agents "falsifying" -as public opinions- their own preferences. 
It was builded to describe, explore, experiment and understand how simple heuristics can modulate global opinion dynamics.

## HOW IT WORKS

So far two mechanisms are implemented: a version of Festiguer's reduction of cognitive disonance, and a version of Goffman's impression management. In certain social contexts -minority, social rank presure- some models agents can "fake" its public opinion while keeping internally the oposite preference, but after a number of rounds following this falsifying behaviour pattern, a coherence principle can change the real or internal preferences close to that expressed in public.


## HOW TO USE IT

The simulation model allows for a number of diferent initial setup, controlled by homophily level (S) and Global/Close-neigbourhood social influence propension (P).


## HOW TO CITE

If you mention this model or the NetLogo software in a publication, we ask that you include the citations below.

For the model itself:

Miguel, F. J., León, F. J. & Tena-Sánchez, J. (2019). "PFS - Preference Falsification Simulation (PreFalSim) v1.4.0". ComSES Net / OpenABM Computational library

For the original paper:

León, F. J. & Tena-Sánchez, J., & Miguel, F. J.. (2019). Fakers Becoming Believers: How opinion dynamics are shaped by preference falsification, impression management and coherence heuristics. Quality and Quantity. International Journal of Methodology. doi:10.1007/s11135-019-00909-2

Please cite the NetLogo software as:

Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

## COPYRIGHT AND LICENSE

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

0
false
0
Rectangle -16777216 false false 0 0 300 300
Rectangle -1 true false 120 75 210 90
Rectangle -1 true false 120 210 210 225
Rectangle -1 true false 105 90 120 210
Rectangle -1 true false 210 90 225 210

1
false
0
Rectangle -16777216 false false 0 0 300 300
Rectangle -16777216 true false 135 225 210 240
Rectangle -16777216 true false 165 75 180 225
Polygon -16777216 true false 165 75 135 120 150 120 180 75
Line -16777216 false 135 240 210 240

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

festinger
false
0
Rectangle -1184463 true false 15 30 30 120
Rectangle -1184463 true false 15 15 75 30
Rectangle -1184463 true false 15 60 60 75

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

goffman
false
0
Rectangle -13840069 true false 30 180 60 195
Rectangle -13840069 true false 15 195 30 270
Rectangle -13840069 true false 60 240 75 285
Rectangle -13840069 true false 30 270 60 285
Rectangle -13840069 true false 60 195 75 210
Rectangle -13840069 true false 45 225 75 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="PF_100x_ticks" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>fakers-0</metric>
    <metric>fakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="300"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PF_100x_runs" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>meanfakers-0</metric>
    <metric>meanfakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="300"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PF_100x3_ticks" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>fakers-0</metric>
    <metric>fakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PF_1x1000_ticks" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>fakers-0</metric>
    <metric>fakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PF_1x1000_ticks_p01" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>fakers-0</metric>
    <metric>fakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PF_1x1000_ticks_P03" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>fakers-0</metric>
    <metric>fakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PF_1x1000_ticks_P05" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>got-1</metric>
    <metric>xmean</metric>
    <metric>fakers-0</metric>
    <metric>fakers-1</metric>
    <enumeratedValueSet variable="p">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PFS_XZF_xSxP_t500_rep100" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>Xmean</metric>
    <metric>Xdev</metric>
    <metric>Zmean</metric>
    <metric>Zdev</metric>
    <metric>Fprob</metric>
    <steppedValueSet variable="p" first="0" step="0.1" last="1"/>
    <steppedValueSet variable="segregation_level" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="Rounds">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SeeFakers?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="crises">
      <value value="&quot;b 0 0 0\nc 0 0 0 L\nd 0 0 0\nh 0 0 0&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PFS_ZXF1F0_3Sx3P_t300_rep100" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>Xmean</metric>
    <metric>Zmean</metric>
    <metric>F1prob</metric>
    <metric>F0prob</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SeeFakers?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="crises">
      <value value="&quot;b 0 0 0\nc 0 0 0 L\nd 0 0 0\nh 0 0 0&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PFS_XZF_xSxP_t300_rep20" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>Xmean</metric>
    <metric>Xdev</metric>
    <metric>Zmean</metric>
    <metric>Zdev</metric>
    <metric>Fprob</metric>
    <steppedValueSet variable="p" first="0" step="0.1" last="1"/>
    <steppedValueSet variable="segregation_level" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="Rounds">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="crises">
      <value value="&quot;b 0 0 0\nc 0 0 0 L\nd 0 0 0\nh 0 0 0&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="PFS_ZXF1F0_3Sx5P_t300_rep100" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>Xmean</metric>
    <metric>Zmean</metric>
    <metric>F1prob</metric>
    <metric>F0prob</metric>
    <enumeratedValueSet variable="p">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="segregation_level">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Rounds">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
